#!/usr/bin/env python

"""
Zope adapter.
"""

import WebStack.Zope

from Globals import Persistent
from OFS.SimpleItem import Item
from AccessControl import ClassSecurityInfo
#from ZPublisher.HTTPResponse import status_reasons

class WebStackAdapterProduct(Persistent, Item):

    "A WebStack adapter product superclass."

    def __init__(self, id, resource, authenticator=None, permission=None):

        """
        Initialise with an 'id', a WebStack 'resource', and an optional
        'authenticator'. The optional 'permission' is a Zope-related security
        identifier.
        """

        self.id = id
        self.webstack_resource = resource
        self.webstack_authenticator = authenticator
        self.security = ClassSecurityInfo()

        if authenticator is None:
            self.security.declarePublic("index_html")
        else:
            permission = permission or "View"
            self.security.declareProtected(permission, "index_html")

    def __bobo_traverse__(self, request, entry_name):
        if entry_name == "index_html":
            return getattr(self, "index_html")
        return self

    def index_html(self, REQUEST=None):

        """
        Dispatch the given 'REQUEST' to the root application-specific WebStack
        resource.
        """

        if REQUEST is not None:
            trans = WebStack.Zope.Transaction(REQUEST)
        else:
            raise "Internal Error"

        if self.webstack_authenticator is None or self.webstack_authenticator.authenticate(trans):
            self.webstack_resource.respond(trans)
        else:
            #trans.set_header_value("WWW-Authenticate", '%s realm="%s"' % (
            #    self.webstack_authenticator.get_auth_type(), self.webstack_authenticator.get_realm()))
            raise "Unauthorized"

        trans.commit()
        #raise status_reasons[trans.get_response_code()]

# vim: tabstop=4 expandtab shiftwidth=4
